[Schmitzm-commits] r1497 - in trunk/schmitzm-gt/src/main/java/de/schmitzm/geotools: . styling
scm-commit@wald.intevation.org
scm-commit at wald.intevation.org
Wed Feb 9 19:57:46 CET 2011
Author: alfonx
Date: 2011-02-09 19:57:45 +0100 (Wed, 09 Feb 2011)
New Revision: 1497
Modified:
trunk/schmitzm-gt/src/main/java/de/schmitzm/geotools/GTUtil.java
trunk/schmitzm-gt/src/main/java/de/schmitzm/geotools/styling/StyledLayerUtil.java
Log:
Added GTUtil.descriptionTitle( Description ) to get the descrptions title without checking for null three times....
Modified: trunk/schmitzm-gt/src/main/java/de/schmitzm/geotools/GTUtil.java
===================================================================
--- trunk/schmitzm-gt/src/main/java/de/schmitzm/geotools/styling/StyledLayerUtil.java 2011-02-08 18:31:15 UTC (rev 1496)
+++ trunk/schmitzm-gt/src/main/java/de/schmitzm/geotools/styling/StyledLayerUtil.java 2011-02-09 18:57:45 UTC (rev 1497)
@@ -91,6 +91,7 @@
import com.vividsolutions.jts.geom.Geometry;
import de.schmitzm.geotools.FilterUtil;
+import de.schmitzm.geotools.GTUtil;
import de.schmitzm.geotools.JTSUtil;
import de.schmitzm.geotools.LegendIconFeatureRenderer;
import de.schmitzm.geotools.data.amd.AttributeMetadataImpl;
@@ -1004,7 +1005,8 @@
// hbox.add(Box.createHorizontalStrut(3));
final Translation labelT = new Translation();
- labelT.fromOneLine(rule.getDescription().getTitle().toString());
+ labelT.fromOneLine(GTUtil.descriptionTitle(rule
+ .getDescription()));
final JLabel classTitleLabel = new JLabel(labelT.toString());
panel.add(classTitleLabel, "sgx2");
More information about the Schmitzm-commits
mailing list
--- trunk/schmitzm-gt/src/main/java/de/schmitzm/geotools/GTUtil.java 2011-02-08 18:31:15 UTC (rev 1496)
+++ trunk/schmitzm-gt/src/main/java/de/schmitzm/geotools/GTUtil.java 2011-02-09 18:57:45 UTC (rev 1497)
@@ -56,6 +56,7 @@
import org.geotools.renderer.label.LabelCacheImpl;
import org.geotools.renderer.lite.StreamingRenderer;
import org.geotools.renderer.shape.ShapefileRenderer;
+import org.geotools.styling.Description;
import org.opengis.feature.simple.SimpleFeature;
import org.opengis.feature.simple.SimpleFeatureType;
import org.opengis.geometry.Envelope;
@@ -67,7 +68,6 @@
import de.schmitzm.swing.input.ManualInputOption;
import de.schmitzm.swing.input.ManualInputOption.Text;
-
/**
* Diese Klasse enthaelt allgemeine Funktionen fuer die Arbeit mit Geotools.
*
@@ -541,8 +541,6 @@
throw new RuntimeException(e);
}
}
-
-
/**
* Erzeugt eine neue Eingabe-Option, in der eine Eingabe zwingend
@@ -552,7 +550,8 @@
* Beschreibung
*/
public static ManualInputOption createTextInputOption(Param param) {
- Text mi = new ManualInputOption.Text(param.title.toString(), param.required);
+ Text mi = new ManualInputOption.Text(param.title.toString(),
+ param.required);
mi.setToolTipText(param.description.toString());
return mi;
}
@@ -566,40 +565,52 @@
* @param defValue
* Wert der im Textfeld vorgeblendet wird
*/
- public static ManualInputOption createTextInputOption(Param param, String defValue) {
- Text ti = new ManualInputOption.Text(param.title.toString(), param.required, defValue);
+ public static ManualInputOption createTextInputOption(Param param,
+ String defValue) {
+ Text ti = new ManualInputOption.Text(param.title.toString(),
+ param.required, defValue);
ti.setToolTipText(param.description.toString());
return ti;
}
+ /**
+ * Returns desc.getTitle().toString() and <code>null</code> if any of these
+ * is <code>null</code>.
+ */
+ public static String descriptionTitle(Description desc) {
+ if (desc == null)
+ return null;
+ if (desc.getTitle() == null)
+ return null;
+ return desc.getTitle().toString();
+ }
-// /**
-// * Erzeugt eine neue Eingabe-Option, in der eine Eingabe zwingend
-// * erforderlich ist.
-// *
-// * @param label
-// * Beschreibung
-// * @param defValue
-// * Wert der im Textfeld vorgeblendet wird
-// */
-// public Integer(Param param) {
-// this(param.title.toString(), param.required);
-// setToolTipText(param.description.toString());
-// }
-//
-// /**
-// * Erzeugt eine neue Eingabe-Option, in der eine Eingabe zwingend
-// * erforderlich ist.
-// *
-// * @param label
-// * Beschreibung
-// * @param defValue
-// * Wert der im Textfeld vorgeblendet wird
-// */
-// public Integer(Param param, java.lang.Integer defValue) {
-// this(param.title.toString(), param.required, defValue);
-// setToolTipText(param.description.toString());
-// }
+ // /**
+ // * Erzeugt eine neue Eingabe-Option, in der eine Eingabe zwingend
+ // * erforderlich ist.
+ // *
+ // * @param label
+ // * Beschreibung
+ // * @param defValue
+ // * Wert der im Textfeld vorgeblendet wird
+ // */
+ // public Integer(Param param) {
+ // this(param.title.toString(), param.required);
+ // setToolTipText(param.description.toString());
+ // }
+ //
+ // /**
+ // * Erzeugt eine neue Eingabe-Option, in der eine Eingabe zwingend
+ // * erforderlich ist.
+ // *
+ // * @param label
+ // * Beschreibung
+ // * @param defValue
+ // * Wert der im Textfeld vorgeblendet wird
+ // */
+ // public Integer(Param param, java.lang.Integer defValue) {
+ // this(param.title.toString(), param.required, defValue);
+ // setToolTipText(param.description.toString());
+ // }
-
}
Modified: trunk/schmitzm-gt/src/main/java/de/schmitzm/geotools/styling/StyledLayerUtil.java
===================================================================